<?php

/**
 * Move 2 Spam
 *
 * Sample plugin that adds a new button to the mailbox toolbar
 * to move messages labeled as "spam" to the Junk folder
 *
 * @version @package_version@
 * @license GNU GPLv3+
 * @author Anderson C. Santos
 * Based on the Markasjunk plugin by Thomas Bruederli and
 * Based on the Markasjunk2 plugin by Philip Weir and
 * Based on the Movespam plugin by Ythan
 */
class move2spam extends rcube_plugin
{
  public $task = 'mail';
  private $spam_text = '[ SPAM ]';
  private $move_seen = true;

  function init()
  {
    $rcmail = rcmail::get_instance();

    $this->load_config();
    $this->spam_text = $rcmail->config->get('move2spam_subject', null);
    $this->move_seen = $rcmail->config->get('move2spam_seen', null);

    $this->add_texts('localization/', true);

    $this->register_action('plugin.move2spam', array($this, 'move_to_spam_folder'));

    $this->include_script('move2spam.js');

    $skin = $rcmail->config->get('skin');
    if (!file_exists($this->home."/skins/$skin/move2spam.css"))
      $skin = 'default';

    $this->include_stylesheet("skins/$skin/move2spam.css");

    $this->add_button(
      array(
       'type' => 'link',
       'command' => 'plugin.move2spam',
       'class' => 'button buttonPas move2spam enabled',
       'classact' => 'button move2spam',
       'title' => 'buttontitle',
       'label' => 'buttontext',
       'domain' => 'move2spam'), 'toolbar');
  }

  function move_to_spam_folder()
  {
    $rcmail    = rcmail::get_instance();

    $mbox      = $rcmail->storage->get_folder();
    $junk_mbox = $rcmail->config->get('junk_mbox');

    if ($mbox != $junk_mbox) {

      $a_headers = $rcmail->storage->list_messages($mbox, NULL, NULL, NULL);

      if(count($a_headers)) {

        $msgtext = $this->gettext(array('name' => 'searchingmessages', 'vars' => array('count' => sizeof($a_headers))));
	$rcmail->output->command('display_message', $msgtext, 'notice');

        foreach($a_headers as $message){
          if (strpos($message->subject, $this->spam_text) === 0){
            if (!$message->flags[SEEN] || $this->move_seen) {
              $spam_uids[] = $message->uid;
            }
          }
        }

        if (count($spam_uids)){

          $msgtext = $this->gettext(array('name' => 'movingmessages', 'vars' => array('count' => count($spam_uids))));
          $rcmail->output->command('display_message', $msgtext, 'notice');

          $spam_uids_str = implode(',', $spam_uids);

          $rcmail->imap->move_message($spam_uids_str, $junk_mbox, $mbox);

          $unseen_count = $rcmail->imap->count($junk_mbox, 'UNSEEN');
          $rcmail->output->command('set_unread_count', $junk_mbox, $unseen_count, false);

          $this->api->output->command('list_mailbox');
          $this->api->output->send();
          $this->api->output->command('getunread');
          $this->api->output->send();

          $msgtext = $this->gettext(array('name' => 'messagesmoved', 'vars' => array('count' => count($spam_uids))));
          $rcmail->output->command('display_message', $msgtext, 'confirmation');

        } else {

          $rcmail->output->command('display_message', $this->gettext('nospamtomove'), 'confirmation');

	}

      } else {

        $rcmail->output->command('display_message', $this->gettext('nomessagetosearch'), 'confirmation');

      }

    } else {

      $rcmail->output->command('display_message', $this->gettext('needoutofspambox'), 'error');

    }
    
  }

}
